def trial(input:str = " ", s:str = " ") -> tuple[str,str]:

    standard_prompt = '''Write a coherent passage of 4 short paragraphs. The end sentence of each paragraph must be: {input}'''

    cot_prompt = '''Write a coherent passage of 4 short paragraphs. The end sentence of each paragraph must be: {input}. Make a plan then write. Your output should be of the following format:
    
    Plan:
    Your plan here.
    
    Passage:
    Your passage here.
    '''
    
    vote_prompt = '''Given an instruction and several choices, decide which choice is most promising. Analyze each choice in detail, then conclude in the last line "The best choice is {s}", where s the integer id of the choice.'''

    compare_prompt = '''Briefly analyze the coherency of the following two passages. Conclude in the last line "The more coherent passage is 1", "The more coherent passage is 2", or "The two passages are similarly coherent".'''

    score_prompt = '''Analyze the following passage, then at the last line conclude "Thus the coherency score is {s}", where s is an integer from 1 to 10.'''

    return standard_prompt, cot_prompt, vote_prompt, compare_prompt, score_prompt
